using System;
using System.Collections;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text;

namespace RollOverImageDemo
{
	/// <summary> 
	/// Utility class for an ASP.NET page that preloads images that
	/// are used for mouseovers.
	/// 
	/// Be sure to notice that this code is provided as a technology sample, 
	/// 'as is' and no warranties are made by the authors. 
	/// 
	/// For questions and comments: i.j.m.c.schepers@wxs.nl, 
	///                             Fons.Sonnemans@reflectionit.nl
	/// 
	/// </summary> 
	public class RollOverImageManager
	{
		private ArrayList mImages;
		
		/// <summary>
		/// Constructor
		/// </summary>
		public RollOverImageManager()
		{
			mImages = new ArrayList();
		}

		/// <summary>
		/// Add a image to the Pre-loadlist
		/// </summary>
		/// <param name="imageURL"></param>
		public void AddImage(string imageURL)
		{
			mImages.Add(imageURL);
		}

		/// <summary>
		/// Initialize the Image (and ImageButton) control
		/// </summary>
		/// <param name="control"></param>
		/// <param name="imageURLMouseOver"></param>
		public void InitializeImage(Image control, string imageURLMouseOver)
		{
			InitializeImage(control, imageURLMouseOver, control.ImageUrl);
		}

		/// <summary>
		/// Initialize the Image (and ImageButton) control
		/// </summary>
		/// <param name="control"></param>
		/// <param name="imageURLMouseOver"></param>
		/// <param name="imageURLMouseOut"></param>
		public void InitializeImage(Image control, 
			                        string imageURLMouseOver, 
			                        string imageURLMouseOut)
		{
			AddImage(imageURLMouseOver);
			
			AddAttribute(control.Attributes, "onMouseOut", imageURLMouseOut);
			AddAttribute(control.Attributes, "onMouseOver", imageURLMouseOver);
			
		}

		/// <summary>
		/// Initialize the HtmlImage (and ImageButton) control
		/// </summary>
		/// <param name="control"></param>
		/// <param name="imageURLMouseOver"></param>
		public void InitializeImage(HtmlImage control, string imageURLMouseOver)
		{
			InitializeImage(control, imageURLMouseOver, control.Src);
		}

		/// <summary>
		/// Initialize the HtmlImage (and ImageButton) control
		/// </summary>
		/// <param name="control"></param>
		/// <param name="imageURLMouseOver"></param>
		/// <param name="imageURLMouseOut"></param>
		public void InitializeImage(HtmlImage control, 
			                        string imageURLMouseOver, 
			                        string imageURLMouseOut)
		{
			AddImage(imageURLMouseOver);
			
			AddAttribute(control.Attributes, "onMouseOut", imageURLMouseOut);
			AddAttribute(control.Attributes, "onMouseOver", imageURLMouseOver);
			
		}

		/// <summary>
		/// Add the 'this.src' event-attribute to the collection
		/// </summary>
		/// <param name="a">collection</param>
		/// <param name="eventName">Eventname</param>
		/// <param name="imageUrl">ImageUrl</param>
		public void AddAttribute(AttributeCollection a, 
			                     string eventName, 
			                     string imageUrl)
		{
			try 
			{ 
				a.Remove(eventName); 
			} 
			finally 
			{ 
				a.Add(eventName, "this.src='" + imageUrl + "'"); 
			} 
		}

		/// <summary> 
		/// Preload the images
		/// </summary> 
		public void LoadImages(Page webPage)
		{
			// Create JavaScript
			StringBuilder buildString = new StringBuilder();
			buildString.Append("\n<SCRIPT LANGUAGE='JavaScript'>\n"); 
			buildString.Append("<!--\n"); 
			buildString.Append("var aImages = new Array();\n");
			for(int i = 0; i < mImages.Count; i++)
			{
				buildString.Append("aImages[" + 
					i + "] = new Image();\n");
				buildString.Append("aImages[" + 
					i + "].src = '" + 
					mImages[i].ToString() + "';\n");
			}
			buildString.Append("//-->\n");
			buildString.Append("</script>\n");

			// Register Client Script
			if (webPage == null)
			{
				throw new ArgumentException( 
					"The Page object is invalid."); 
			}
			if (webPage.Request.Browser.JavaScript == true) 
			{ 
				webPage.RegisterClientScriptBlock("ImageLoader", 
					buildString.ToString());
			}
		}
	
	}
}
